summaryrefslogtreecommitdiff
path: root/src/node/utils
diff options
context:
space:
mode:
authorLuiza Pagliari <lpagliari@gmail.com>2015-09-07 03:55:56 -0700
committerLuiza Pagliari <lpagliari@gmail.com>2015-09-07 03:55:56 -0700
commited5262650af5feeb20bab2fa6173a0fe84821492 (patch)
treeaf3d0eb65d7010ba8061ae756c4b7922cbeff9f1 /src/node/utils
parent1a5985dc759c33e614eaa53ba9c4d2489c9e3495 (diff)
downloadetherpad-lite-ed5262650af5feeb20bab2fa6173a0fe84821492.zip
Generating pad HTML with tags like <span data-TAG="VALUE"> instead of <TAG:VALUE>
Diffstat (limited to 'src/node/utils')
-rw-r--r--src/node/utils/ExportHtml.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/node/utils/ExportHtml.js b/src/node/utils/ExportHtml.js
index c5936cf9..ccdc3a59 100644
--- a/src/node/utils/ExportHtml.js
+++ b/src/node/utils/ExportHtml.js
@@ -81,10 +81,10 @@ function getHTMLFromAtext(pad, atext, authorColors)
hooks.aCallAll("exportHtmlAdditionalTags", pad, function(err, newProps){
// newProps can be simply a string (which means it is stored as attribute in the form of ['tag', 'true'])
// or it can be a pair of values in an Array (for the case when it is stored as ['tag', 'value']).
// The later scenario will generate HTML with tags like <tag:value>
newProps.forEach(function (propName, i){
if (_.isArray(propName)) {
- tags.push(propName[0] + ":" + propName[1]);
+ tags.push('span data-' + propName[0] + '="' + propName[1] + '"');
} else {
tags.push(propName);
}
@@ -81,10 +81,10 @@ function getHTMLFromAtext(pad, atext, authorColors)
// newProps can be simply a string (which means it is stored as attribute in the form of ['tag', 'true'])
// or it can be a pair of values in an Array (for the case when it is stored as ['tag', 'value']).
- // The later scenario will generate HTML with tags like <tag:value>
+ // The later scenario will generate HTML with tags like <span data-tag="value">
newProps.forEach(function (propName, i){
if (_.isArray(propName)) {